==> en_bot_sdk-1.0.5.tar.gz: lib/en_bot_sdk.dart <==

import 'dart:ffi';
import 'dart:core';
import 'dart:io';
import 'dart:typed_data';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

enum EnBotSdk_LanguageDirection {
  defaultDirection,
  rtl,
}

class EnBotSdk {
  static const MethodChannel _channel = MethodChannel('en_bot_sdk');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  Future<Object?> launchBot(
  BuildContext context,
      String botKey,
      String botName,
      String brandingKey,
      String userId,
      int chatHistorySize,
      bool showDone,
      EnBotSdk_LanguageDirection languageDirection,
      String headerTitleFont,
      String headerDescriptionFont,
      String sendMessageButtonIconPath
      ) async
  {
    Uint8List? listData;
    if (sendMessageButtonIconPath != "") {
      try {
        final byteData = await rootBundle.load(sendMessageButtonIconPath);
        listData = Uint8List.view(byteData.buffer);
      } on Exception catch (exception) {
        print("Invalid image");
      }
    }



    // final Uint8List imageData = File(sendMessageButtonIconPath).readAsBytesSync();
    Object? obj = await _channel.invokeMethod('launchBot', <String, dynamic>{
      'botKey':botKey,
      'botName': botName,
      'brandingKey': brandingKey,
      'userId': userId,
      'chatHistorySize': chatHistorySize,
      'showDone': showDone,
      'languageDirection': languageDirection.index,
      'headerTitleFont': headerTitleFont,
      'headerDescriptionFont': headerDescriptionFont,
      'sendMessageButtonIcon':listData ?? null
    });

  }
}

==> en_bot_sdk-1.0.9.tar.gz: lib/en_bot_sdk.dart <==
import 'dart:ffi';
import 'dart:core';
import 'dart:io';
import 'dart:typed_data';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

enum EnBotSdk_LanguageDirection {
  defaultDirection,
  rtl,
}

/// EnBotSdk
///
/// Helps you to launch chat bot
///
class EnBotSdk {
  static const MethodChannel _channel = MethodChannel('en_bot_sdk');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  /// launchBot
  ///
  /// Will launch bot with specified botKey and other paramaters
  ///
  /// Returns object in when user taps on done button (if enabled)
  ///
  Future<Object?> launchBot(
      BuildContext context,
      String botKey,
      String botName,
      String brandingKey,
      String userId,
      int chatHistorySize,
      bool showDone,
      EnBotSdk_LanguageDirection languageDirection,
      String headerTitleFont,
      String headerDescriptionFont,
      String sendMessageButtonIconPath) async {
    Uint8List? listData;
    if (sendMessageButtonIconPath != "") {
      try {
        final byteData = await rootBundle.load(sendMessageButtonIconPath);
        listData = Uint8List.view(byteData.buffer);
      } on Error catch (exception) {
        print("Exception loading image");
      }
    }

    Object? obj = await _channel.invokeMethod('launchBot', <String, dynamic>{
      'botKey': botKey,
      'botName': botName,
      'brandingKey': brandingKey,
      'userId': userId,
      'chatHistorySize': chatHistorySize,
      'showDone': showDone,
      'languageDirection': languageDirection.index,
      'headerTitleFont': headerTitleFont,
      'headerDescriptionFont': headerDescriptionFont,
      'sendMessageButtonIcon': listData ?? null
    });
  }
}
